# -*- coding: utf-8 -*-

from .exceptions import CircularDependencyError

class Node:
    def __init__(self, name, depends, instance):
        self.name = name
        # Remove the node from its own dependencies
        self.depends = set(depends) - {name}
        self.instance = instance

class DepSolver:
    def __init__(self):
        self.nodes = []

    def add(self, name, depends, instance):
        self.nodes.append(Node(name, depends, instance))

    def solve(self):
        # Returns a list of instances ordered by dependency
        deps = {node.name: node for node in self.nodes}
        result = []
        while deps:
            # Get a batch of nodes not depending on anything (or originally depending on already resolved nodes)
            batch = {name for name, node in deps.items() if not node.depends}
            if not batch:
                # If there are no such nodes, we have found a circular dependency
                raise CircularDependencyError(deps)
            # Add instances tied to the resolved keys to the result and remove resolved keys from the dependecy map
            for name in batch:
                result.append(deps[name].instance)
                del deps[name]
            # Remove resolved keys from the dependencies of yet unresolved nodes
            for node in deps.values():
                node.depends -= batch
        return result
